@@ -1,12 +1,5 @@
-##
-# name:      IO::All::Filesys
-# author:    Ingy döt Net
-# abstract:  Filesys Base Class
-# license:   perl
-# copyright: 2004, 2006, 2008, 2010, 2012
-
 package IO::All::Filesys;
-use IO::All::OO;
+use IO::All::Base;
 extends 'IO::All::IO';
 
 has name => ();
