@@ -1,12 +1,5 @@
-##
-# name:      IO::All::IO
-# author:    Ingy döt Net
-# abstract:  Base Class for Various IO::All Objects
-# license:   perl
-# copyright: 2012
-
 package IO::All::IO;
-use IO::All::OO;
+use IO::All::Base;
 
 has upgrade_methods => ( default => sub { [] } );
 
